@@ -1,5 +1,5 @@
 package ExtUtils::Builder::MakeMaker;
-$ExtUtils::Builder::MakeMaker::VERSION = '0.008';
+$ExtUtils::Builder::MakeMaker::VERSION = '0.009';
 use strict;
 use warnings;
 
@@ -48,6 +48,13 @@ sub postamble {
 	$planner->add_delegate('uninst', sub { $maker->{UNINST} });
 	$planner->add_delegate('meta', sub { CPAN::Meta->load_file('META.json') });
 	$planner->add_delegate('release_status', sub { CPAN::Meta->load_file('META.json')->release_status });
+	$planner->add_delegate('jobs', sub { 1 });
+
+	$planner->add_delegate('new_planner', sub {
+		my $inner = ExtUtils::Builder::Planner->new;
+		$inner->add_delegate('config', sub { $config });
+		return $inner;
+	});
 
 	$maker->make_plans($planner, %args) if $maker->can('make_plans');
 	for my $file (glob 'planner/*.pl') {
@@ -84,7 +91,7 @@ ExtUtils::Builder::MakeMaker - A MakeMaker consumer for ExtUtils::Builder Plan o
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
